@@ -120,6 +120,7 @@ class ProviderRequestProxy(object):
         return self.request_with_retry('delete', **request_arguments)
 
     def format_return_data(self, response):
+        # TODO: decouple it
         if response.status_code == 204 or self.raw:
             return response
         elif self.is_json:
@@ -148,7 +149,6 @@ class ProviderRequestProxy(object):
                                       response.url,
                                       response.content)
                     raise ProviderHTTPClientException(http_error_msg, response=response)
-                # TODO: add more retryable exceptions code
                 elif response.status_code in [502, 503]:
                     raise RetryableException('Deployment might be in progress, or server is overloaded')
                 elif 500 <= response.status_code < 600:
@@ -193,16 +193,25 @@ def remote_service(path, headers=None, timeout=None, json=True, raw=False):
             authentication_headers = provider.get_provider_headers()
             headers.update(authentication_headers)
 
-            session = ProviderRequestProxy(provider.build_url(path),
-                                           headers,
-                                           timeout=timeout or provider.timeout,
-                                           retries=provider.retries,
-                                           json=json,
-                                           raw=raw,
-                                           host=provider.host)
+            url = provider.build_url(path)
+            raw_override = kwargs.get('raw')
+
+            session = ProviderRequestProxy(
+                url,
+                headers,
+                timeout=timeout or provider.timeout,
+                retries=provider.retries,
+                json=json,
+                raw=raw_override or raw,
+                host=provider.host
+            )
 
             provider.session = session
             self.session = session
+
+            setattr(func, 'provider', provider)
+            setattr(func, 'url', url)
+
             return func(provider, *args, **kwargs)
 
         return inner
