@@ -4,6 +4,7 @@ import six
 
 from rebotics_sdk.providers.utils import hash_file, accept_file
 from .base import ReboticsBaseProvider, remote_service, PageResult
+from ..advanced.flows import FeatureVectorFlow
 
 
 class RetailerProvider(ReboticsBaseProvider):
@@ -16,7 +17,7 @@ class RetailerProvider(ReboticsBaseProvider):
         return self.session.get()
 
     @remote_service('/api/v4/token-auth/')
-    def token_auth(self, username, password):
+    def token_auth(self, username, password, **kwargs):
         json_data = self.session.post(data={
             'username': username,
             'password': password
@@ -32,7 +33,7 @@ class RetailerProvider(ReboticsBaseProvider):
         return response['token']
 
     @remote_service('/api/v4/processing/actions/{id}/requeue/')
-    def requeue(self, processing_action_id, requeue_type=None):
+    def requeue(self, processing_action_id, requeue_type=None, **kwargs):
         data = {}
 
         if requeue_type is not None:
@@ -41,27 +42,27 @@ class RetailerProvider(ReboticsBaseProvider):
         return self.session.post(id=processing_action_id, data=data)
 
     @remote_service('/api/v4/processing/actions/{id}/cancel/')
-    def cancel(self, processing_action_id):
+    def cancel(self, processing_action_id, **kwargs):
         return self.session.post(id=processing_action_id)
 
     @remote_service('/api/v4/processing/actions/{id}/recalculate/')
-    def recalculate(self, processing_action_id):
+    def recalculate(self, processing_action_id, **kwargs):
         return self.session.post(id=processing_action_id)
 
     @remote_service('/api/v4/processing/actions/{id}/')
-    def processing_action_detail(self, processing_action_id):
+    def processing_action_detail(self, processing_action_id, **kwargs):
         return self.session.get(id=processing_action_id)
 
     @remote_service('/api/v4/processing/actions/{id}/realogram/')
-    def processing_action_realogram_detail(self, processing_action_id):
+    def processing_action_realogram_detail(self, processing_action_id, **kwargs):
         return self.session.get(id=processing_action_id)
 
     @remote_service('/api/v4/processing/actions/{id}/')
-    def processing_action_delete(self, processing_action_id):
+    def processing_action_delete(self, processing_action_id, **kwargs):
         return self.session.delete(id=processing_action_id)
 
     @remote_service('/api/v4/processing/actions/{id}/send_oos_notification/')
-    def send_oos_notification(self, processing_action_id, force=False):
+    def send_oos_notification(self, processing_action_id, force=False, **kwargs):
         return self.session.post(id=processing_action_id, data={
             'force': force
         })
@@ -128,7 +129,7 @@ class RetailerProvider(ReboticsBaseProvider):
         return self.session.post(json=data)
 
     @remote_service('/api/v4/processing/upload/')
-    def processing_upload(self, store_id, input_file, input_type='image'):
+    def processing_upload(self, store_id, input_file, input_type='image', **kwargs):
         """Upload files that can be used for processing action creation"""
         assert isinstance(store_id, int), 'You need to specify store_id as int'
         assert input_type in (
@@ -169,11 +170,11 @@ class RetailerProvider(ReboticsBaseProvider):
         )
 
     @remote_service('/api/v4/processing/upload/request/{id}/finish/')
-    def notify_processing_upload_finished(self, id_):
+    def notify_processing_upload_finished(self, id_, **kwargs):
         return self.session.post(id=id_)
 
     @remote_service('/api/v4/export/products/')
-    def export_products(self, products_filter=None, page=1):
+    def export_products(self, products_filter=None, page=1, **kwargs):
         params = {
             'page': page,
             'page_size': 100,
@@ -183,7 +184,7 @@ class RetailerProvider(ReboticsBaseProvider):
         return PageResult(self.session.get(params=params))
 
     @remote_service('/api/v4/export/products/{product_id}/previews/')
-    def get_product_previews(self, product_id, is_removed=None, page=1):
+    def get_product_previews(self, product_id, is_removed=None, page=1, **kwargs):
         params = {
             'page': page,
         }
@@ -197,12 +198,12 @@ class RetailerProvider(ReboticsBaseProvider):
         ))
 
     @remote_service('/api/v4/export/products/previews/', timeout=30000)
-    def get_product_previews_bulk(self, product_id_list):
+    def get_product_previews_bulk(self, product_id_list, **kwargs):
         filter_params = {'id': product_id_list}
         return self.session.post(data=filter_params)
 
     @remote_service('/api/v4/products/previews/')
-    def upload_product_preview(self, upc, image_file):
+    def upload_product_preview(self, upc, image_file, **kwargs):
         return self.session.post(data={
             'product_unique_id': upc,
         }, files={
@@ -210,13 +211,13 @@ class RetailerProvider(ReboticsBaseProvider):
         })
 
     @remote_service('/api/v4/products/previews/delete/')
-    def delete_product_previews(self, upc):
+    def delete_product_previews(self, upc, **kwargs):
         return self.session.post(data={
             'product_unique_id': upc
         })
 
     @remote_service('/api/v4/products/search/')
-    def get_product_info_by_upc(self, upc_list):
+    def get_product_info_by_upc(self, upc_list, **kwargs):
         if not all(upc.isdigit() for upc in upc_list):
             raise ValueError("Supplied non numeric code in list")
 
@@ -225,7 +226,7 @@ class RetailerProvider(ReboticsBaseProvider):
         }))
 
     @remote_service('/api/v4/product/previews/{preview_id}/add_feature_reference/')
-    def set_product_preview_feature_id(self, preview_id, feature_id, facenet):
+    def set_product_preview_feature_id(self, preview_id, feature_id, facenet, **kwargs):
         return self.session.post(
             preview_id=preview_id,
             data={
@@ -235,7 +236,8 @@ class RetailerProvider(ReboticsBaseProvider):
         )
 
     @remote_service('/api/v4/processing/actions/')
-    def processing_action_list(self, store=None, status=None, aisle=None, section=None, page=1, page_size=100):
+    def processing_action_list(self, store=None, status=None, aisle=None, section=None, page=1, page_size=100,
+                               **kwargs):
         """Request processing action list"""
 
         def set_param(params, key, value):
@@ -256,7 +258,7 @@ class RetailerProvider(ReboticsBaseProvider):
         return PageResult(data)
 
     @remote_service('api/v4/imports/planogram/assign/')
-    def assign_planogram_with_file(self, assign_file, deactivate_old_planograms=False):
+    def assign_planogram_with_file(self, assign_file, deactivate_old_planograms=False, **kwargs):
 
         file_io = None
 
@@ -279,6 +281,7 @@ class RetailerProvider(ReboticsBaseProvider):
         horizontal_direction_shelf_bay='left-to-right',
         is_zig_zag=False,
         convert_upc=False,
+        **kwargs
     ):
         """
         This will also close your file after transmission
@@ -344,7 +347,7 @@ class RetailerProvider(ReboticsBaseProvider):
         return response
 
     @remote_service('api/v4/imports/planogram-assign-file/')
-    def assign_planogram(self, assign_file, deactivate=False):
+    def assign_planogram(self, assign_file, deactivate=False, **kwargs):
         """
         Uploads an assign planogram file to retailer. Be careful to upload it.
         :param assign_file: file-like object
@@ -365,27 +368,27 @@ class RetailerProvider(ReboticsBaseProvider):
         return response
 
     @remote_service('api/v4/store_aisles/{store_id}')
-    def get_store_aisles(self, store_id):
+    def get_store_aisles(self, store_id, **kwargs):
         return self.session.get(store_id=store_id)
 
     @remote_service('api/v4/stores/')
-    def get_stores(self):
+    def get_stores(self, **kwargs):
         return self.session.get()
 
     @remote_service('api/v4/processing_aisles/{processing_id}/')
-    def get_processing_aisles(self, processing_id):
+    def get_processing_aisles(self, processing_id, **kwargs):
         return self.session.get(processing_id=processing_id)
 
     @remote_service('api/v4/users/')
-    def user_list(self):
+    def user_list(self, **kwargs):
         return self.session.get()
 
     @remote_service('api/v4/users/{username}/subscriptions/')
-    def user_subscriptions(self, username):
+    def user_subscriptions(self, username, **kwargs):
         return self.session.get(username=username)
 
     @remote_service('api/v4/users/{username}/subscriptions/')
-    def user_subscriptions_create(self, username, store, aisle, section):
+    def user_subscriptions_create(self, username, store, aisle, section, **kwargs):
         return self.session.post(
             username=username,
             data={
@@ -396,7 +399,7 @@ class RetailerProvider(ReboticsBaseProvider):
         )
 
     @remote_service('api/v1/master-data/file-upload/')
-    def v1_upload_file(self, file):
+    def v1_upload_file(self, file, **kwargs):
         return self.session.post(
             data={
                 'description': 'preview upload from SDK',
@@ -407,7 +410,7 @@ class RetailerProvider(ReboticsBaseProvider):
         )
 
     @remote_service('api/v1/master-data/products/{product_id}/images/')
-    def v1_upload_preview(self, product_id, image_id):
+    def v1_upload_preview(self, product_id, image_id, **kwargs):
         return self.session.post(
             product_id=product_id,
             json={
@@ -415,13 +418,17 @@ class RetailerProvider(ReboticsBaseProvider):
             }, content_type='application/json')
 
     @remote_service('api/v4/processing/actions/{id}/spacial')
-    def get_spacial_data(self, scan_id):
+    def get_spacial_data(self, scan_id, **kwargs):
         """Can yield permission error. Internal usage intended"""
         return self.session.get(id=scan_id)
 
     @remote_service('api/v4/processing/actions/export-to-dataset/')
-    def export_to_dataset(self, scan_ids, batch_size=5):
+    def export_to_dataset(self, scan_ids, batch_size=5, **kwargs):
         return self.session.post(json={
             'scans': sorted(list(set(scan_ids))),
             'batch_size': batch_size,
         })
+
+    @remote_service('/api/v1/rebotics/rpc/export-feature-vector/')
+    def feature_vectors_export(self):
+        return FeatureVectorFlow(self, self.session)
